Requires the requests library.
Events are sent to root + '/publish/epoch/end/' by default. Calls are
HTTP POST, with a data argument which is a
JSON-encoded named list of event data.
If send_as_json = TRUE, the content type of the request will be
"application/json".
Otherwise the serialized JSON will be sent within a form.
Usage
callback_remote_monitor(
root = "http://localhost:9000",
path = "/publish/epoch/end/",
field = "data",
headers = NULL,
send_as_json = FALSE
)Arguments
- root
String; root url of the target server.
- path
String; path relative to
rootto which the events will be sent.- field
String; JSON field under which the data will be stored. The field is used only if the payload is sent within a form (i.e. when
send_as_json = FALSE).- headers
Named list; optional custom HTTP headers.
- send_as_json
Boolean; whether the request should be sent as
"application/json".
Value
A Callback instance that can be passed to fit.keras.src.models.model.Model().
See also
Other callbacks: Callback() callback_backup_and_restore() callback_csv_logger() callback_early_stopping() callback_lambda() callback_learning_rate_scheduler() callback_model_checkpoint() callback_orbax_checkpoint() callback_reduce_lr_on_plateau() callback_swap_ema_weights() callback_tensorboard() callback_terminate_on_nan()