Draws samples from a uniform distribution within [-limit, limit], where
limit = sqrt(6 / fan_in) (fan_in is the number of input units in the
weight tensor).
Arguments
- seed
A integer or instance of
random_seed_generator(). Used to make the behavior of the initializer deterministic. Note that an initializer seeded with an integer orNULL(unseeded) will produce the same random values across multiple calls. To get different random values across multiple calls, use as seed an instance ofrandom_seed_generator().- input_axes
Optional integer vector. The 1-based axes of the input tensor to use when computing the fan-in.
- output_axes
Optional integer vector. The 1-based axes of the output tensor to use when computing the fan-out.
Value
An Initializer instance that can be passed to layer or variable
constructors, or called directly with a shape to return a Tensor.
Examples
# Standalone usage:
initializer <- initializer_he_uniform()
values <- initializer(shape = c(2, 2))# Usage in a Keras layer:
initializer <- initializer_he_uniform()
layer <- layer_dense(units = 3, kernel_initializer = initializer)See also
Other random initializers: initializer_glorot_normal() initializer_glorot_uniform() initializer_he_normal() initializer_lecun_normal() initializer_lecun_uniform() initializer_orthogonal() initializer_random_normal() initializer_random_uniform() initializer_truncated_normal() initializer_variance_scaling()
Other initializers: initializer_constant() initializer_glorot_normal() initializer_glorot_uniform() initializer_he_normal() initializer_identity() initializer_lecun_normal() initializer_lecun_uniform() initializer_ones() initializer_orthogonal() initializer_random_normal() initializer_random_uniform() initializer_stft() initializer_truncated_normal() initializer_variance_scaling() initializer_zeros()